package cv09.test;

import java.io.Serializable;

/**
 * @author Karel Cemus
 */
public abstract class Vehicle implements Comparable<Vehicle>, Serializable {

    private static int next = 1;

    private final int id;

    private final String name;

    private final int price;

    private final int year;

    private Status status;

    protected Vehicle( String name, int price, int year ) {
        this.id = next++;
        this.name = name;
        this.price = price;
        this.year = year;
        this.status = Status.OWNED;
    }

    public static int getNext() {
        return next;
    }

    public int getId() {
        return id;
    }

    public String getName() {
        return name;
    }

    public int getPrice() {
        return price;
    }

    public int getYear() {
        return year;
    }

    public boolean isSold() {
        return Status.SOLD.equals( status );
    }

    public void sell() {
        status = Status.SOLD;
    }

    @Override
    public String toString() {
        return "Vehicle{" +
                "id=" + id +
                ", name='" + name + '\'' +
                ", price=" + price +
                ", year=" + year +
                '}';
    }

    public abstract int getWheels();

    public int getPrice( int discount ) {
        // poradi je  zde dulezite, protoze / je celociselne deleni
        // pokud udelame discount / 100, tak dostaneme 0. 
        // pokud udelame price * (100-discount), tak mame vysoke cislo, 
        // ktere uz klidne 100 delit muzeme celociselne.
        return price * ( 100 - discount ) / 100;
    }

    @Override
    public int compareTo( Vehicle vehicle ) {
        if ( year == vehicle.year ) return name.compareToIgnoreCase( vehicle.name );
        else return year - vehicle.year;
    }

    public static void setNext( int next ) {
        Vehicle.next = next;
    }
}
